pdfs

package
v0.26.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 27, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FormFiller

type FormFiller interface {
	// FillForm fills the src PDF form fields with JSON formatted data and
	// writes the resulting filled PDF to dest.
	FillForm(src io.ReadSeeker, data io.Reader, dest io.Writer) error
}

FormFiller defines the interface for filling PDF forms.

type PDFCPU

type PDFCPU struct {
	// contains filtered or unexported fields
}

func NewPDFCPU

func NewPDFCPU() *PDFCPU

NewPDFCPU creates a new pdfcpu api wrapper using the default pdfcpu configuration. NewPDFCPU is not thread-safe because it reads and writes files in a shared directory (os.UserConfigDir + "/pdfcpu").

func (*PDFCPU) FillForm

func (p *PDFCPU) FillForm(src io.ReadSeeker, data io.Reader, dest io.Writer) error

Directories

Path Synopsis
Package fake is a generated GoMock package.
Package fake is a generated GoMock package.

Jump to