schema

package
v0.27.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AIP added in v0.10.0

type AIP struct {
	ent.Schema
}

AIP holds the schema definition for the AIP entity.

func (AIP) Annotations added in v0.10.0

func (AIP) Annotations() []schema.Annotation

Annotations of the AIP.

func (AIP) Edges added in v0.10.0

func (AIP) Edges() []ent.Edge

Edges of the AIP.

func (AIP) Fields added in v0.10.0

func (AIP) Fields() []ent.Field

Fields of the AIP.

func (AIP) Indexes added in v0.10.0

func (AIP) Indexes() []ent.Index

Indexes of the AIP.

type DeletionRequest added in v0.12.0

type DeletionRequest struct {
	ent.Schema
}

DeletionRequest holds the schema definition for the DeletionRequest entity.

func (DeletionRequest) Annotations added in v0.12.0

func (DeletionRequest) Annotations() []schema.Annotation

Annotations of the DeletionRequest.

func (DeletionRequest) Edges added in v0.12.0

func (DeletionRequest) Edges() []ent.Edge

Edges of the DeletionRequest.

func (DeletionRequest) Fields added in v0.12.0

func (DeletionRequest) Fields() []ent.Field

Fields of the DeletionRequest.

func (DeletionRequest) Indexes added in v0.12.0

func (DeletionRequest) Indexes() []ent.Index

Indexes of the DeletionRequest.

type Location

type Location struct {
	ent.Schema
}

Location holds the schema definition for the Location entity.

func (Location) Annotations

func (Location) Annotations() []schema.Annotation

Annotations of the Location.

func (Location) Edges

func (Location) Edges() []ent.Edge

Edges of the Location.

func (Location) Fields

func (Location) Fields() []ent.Field

Fields of the Location.

func (Location) Indexes

func (Location) Indexes() []ent.Index

Indexes of the Location.

type Task added in v0.12.0

type Task struct {
	ent.Schema
}

Task holds the schema definition for the Task entity.

func (Task) Annotations added in v0.12.0

func (Task) Annotations() []schema.Annotation

Annotations of the Task.

func (Task) Edges added in v0.12.0

func (Task) Edges() []ent.Edge

Edges of the Task.

func (Task) Fields added in v0.12.0

func (Task) Fields() []ent.Field

Fields of the Task.

func (Task) Indexes added in v0.12.0

func (Task) Indexes() []ent.Index

Indexes of the Task.

type Workflow added in v0.12.0

type Workflow struct {
	ent.Schema
}

Workflow holds the schema definition for the Workflow entity.

func (Workflow) Annotations added in v0.12.0

func (Workflow) Annotations() []schema.Annotation

Annotations of the Workflow.

func (Workflow) Edges added in v0.12.0

func (Workflow) Edges() []ent.Edge

Edges of the Workflow.

func (Workflow) Fields added in v0.12.0

func (Workflow) Fields() []ent.Field

Fields of the Workflow.

func (Workflow) Indexes added in v0.12.0

func (Workflow) Indexes() []ent.Index

Indexes of the Workflow.

Jump to