Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AIP ¶ added in v0.10.0
AIP holds the schema definition for the AIP entity.
func (AIP) Annotations ¶ added in v0.10.0
func (AIP) Annotations() []schema.Annotation
Annotations of the AIP.
type DeletionRequest ¶ added in v0.12.0
DeletionRequest holds the schema definition for the DeletionRequest entity.
func (DeletionRequest) Annotations ¶ added in v0.12.0
func (DeletionRequest) Annotations() []schema.Annotation
Annotations of the DeletionRequest.
func (DeletionRequest) Edges ¶ added in v0.12.0
func (DeletionRequest) Edges() []ent.Edge
Edges of the DeletionRequest.
func (DeletionRequest) Fields ¶ added in v0.12.0
func (DeletionRequest) Fields() []ent.Field
Fields of the DeletionRequest.
func (DeletionRequest) Indexes ¶ added in v0.12.0
func (DeletionRequest) Indexes() []ent.Index
Indexes of the DeletionRequest.
type Location ¶
Location holds the schema definition for the Location entity.
func (Location) Annotations ¶
func (Location) Annotations() []schema.Annotation
Annotations of the Location.
type Task ¶ added in v0.12.0
Task holds the schema definition for the Task entity.
func (Task) Annotations ¶ added in v0.12.0
func (Task) Annotations() []schema.Annotation
Annotations of the Task.
type Workflow ¶ added in v0.12.0
Workflow holds the schema definition for the Workflow entity.
func (Workflow) Annotations ¶ added in v0.12.0
func (Workflow) Annotations() []schema.Annotation
Annotations of the Workflow.
Click to show internal directories.
Click to hide internal directories.